/*
 * Copyright 2013-2014 Paul Stöhr
 *
 * This file is part of TD.
 *
 * TD is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.citux.td.ui.fragments;

import android.os.Bundle;
import android.view.MenuItem;
import android.view.View;
import android.widget.AdapterView;

import butterknife.InjectView;
import ch.citux.td.R;
import ch.citux.td.data.model.TwitchGame;
import ch.citux.td.data.model.TwitchGames;
import ch.citux.td.data.model.TwitchGamesElement;
import ch.citux.td.data.service.TDServiceImpl;
import ch.citux.td.data.worker.TDTaskManager;
import ch.citux.td.ui.adapter.GameOverviewAdapter;
import ch.citux.td.ui.widget.EmptyView;
import ch.citux.td.ui.widget.GridView;
import ch.citux.td.util.Log;

public class GameOverviewFragment extends TDFragment<TwitchGames> implements GridView.OnLastItemVisibleListener, AdapterView.OnItemClickListener {

    private static final int LIMIT = 15;

    @InjectView(R.id.empty) EmptyView emptyView;
    @InjectView(R.id.gridview) GridView gridView;

    private GameOverviewAdapter adapter;
    private int offset = 0;
    private boolean loadData = true;

    @Override
    protected int onCreateView() {
        return R.layout.game_overview;
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);
        if (adapter == null) {
            adapter = new GameOverviewAdapter(getActivity());
        }
        gridView.setEmptyView(emptyView);
        gridView.setAdapter(adapter);
        gridView.setOnLastItemVisibleListener(this);
        gridView.setOnItemClickListener(this);
    }

    @Override
    public void loadData() {
        if (loadData) {
            TDTaskManager.executeTask(this);
        }
    }

    @Override
    public TwitchGames startRequest() {
        return TDServiceImpl.getInstance().getTopGames(LIMIT, offset);
    }

    @Override
    public void onResponse(TwitchGames response) {
        if (response != null && response.getTop() != null) {
            for (TwitchGamesElement game : response.getTop()) {
                Log.d(this, game.getGame().getName());
            }
            adapter.addData(response);
            emptyView.setVisibility(View.GONE);
        }
    }

    @Override
    public void onLastItemVisible() {
        offset += LIMIT;
        if (adapter.getTotalCount() > offset + LIMIT) {
            loadData = true;
            loadData();
        }
    }

    @Override
    public void onItemClick(AdapterView<?> parent, View view, int position, long id) {
        TwitchGame game = adapter.getItem(position).getGame();
        if (game != null) {
            Log.d(this, game.getName());

            Bundle args = new Bundle();
            args.putSerializable(GameStreamsFragment.GAME, game);

            getTDActivity().showStreams(args);
            loadData = false;
        }
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        loadData = true;
        return super.onOptionsItemSelected(item);
    }
}
